Header

Struct Header 

pub struct Header {
    pub flags: HeaderFlags,
    pub page_size: PageSize,
    pub commit: PageNum,
    pub min_txid: TXID,
    pub max_txid: TXID,
    pub timestamp: SystemTime,
    pub pre_apply_checksum: Option<Checksum>,
}
An LTX file header.

Fields

flags: HeaderFlags

Flags changing the behavior of LTX encoder/decoder.

page_size: PageSize

The size of the database pages encoded in the file.

commit: PageNum

The size of the database in pages.

min_txid: TXID

Minimum transaction ID in the file.

max_txid: TXID

Maximum transaction ID in the file. May be equal to min_txid if the file contains only one transaction.

timestamp: SystemTime

The time when the LTX file was created.

pre_apply_checksum: Option<Checksum>

Running database checksum before this LTX file is applied. None if the LTX file contains the full snapshot of a database.